@@ -4,6 +4,8 @@ from __future__ import absolute_import
 
 # import apis into api package
 from data_repo_client.api.data_repository_service_api import DataRepositoryServiceApi
+from data_repo_client.api.snapshot_access_request_api import SnapshotAccessRequestApi
+from data_repo_client.api.admin_api import AdminApi
 from data_repo_client.api.configs_api import ConfigsApi
 from data_repo_client.api.datasets_api import DatasetsApi
 from data_repo_client.api.duos_api import DuosApi
